Returns month and year if a postcode was terminated or is no longer active.
Value
A data frame with data about terminated postcode. NULL if postcode is active.
postcodePostcode. All currently terminated postcodes within the United Kingdom, the Channel Islands and the Isle of Man, received every 3 months from Royal Mail. 2, 3 or 4-character outward code, single space and 3-character inward code.year_terminatedTermination year. Year of termination of a postcode.month_terminatedTermination month. Month of termination of a postcode. 1-January, 2-February, ..., 12-December.longitudeLongitude. The WGS84 longitude given the Postcode's national grid reference.latitudeLatitude. The WGS84 latitude given the Postcode's national grid reference.
See https://postcodes.io/docs for more details.
Examples
# \donttest{
terminated_postcode("EC1Y 8LX") # existing postcode
#> Warning: Not Found (HTTP 404).
terminated_postcode("E1W 1UU") # terminated postcode
#> postcode year_terminated month_terminated eastings northings longitude
#> 1 E1W 1UU 2015 2 533779 180545 -0.073706
#> latitude
#> 1 51.50801
# }