Returns a random postcode and all available data for that postcode.
See also
postcode_lookup for documentation.
Examples
# \donttest{
random_postcode()
#> $postcode
#> [1] "BS14 0NZ"
#>
#> $quality
#> [1] 1
#>
#> $eastings
#> [1] 359562
#>
#> $northings
#> [1] 167396
#>
#> $country
#> [1] "England"
#>
#> $nhs_ha
#> [1] "South West"
#>
#> $longitude
#> [1] -2.582729
#>
#> $latitude
#> [1] 51.40414
#>
#> $european_electoral_region
#> [1] "South West"
#>
#> $primary_care_trust
#> [1] "Bristol"
#>
#> $region
#> [1] "South West"
#>
#> $lsoa
#> [1] "Bristol 052D"
#>
#> $msoa
#> [1] "Bristol 052"
#>
#> $incode
#> [1] "0NZ"
#>
#> $outcode
#> [1] "BS14"
#>
#> $parliamentary_constituency
#> [1] "Bristol South"
#>
#> $parliamentary_constituency_2024
#> [1] "Bristol South"
#>
#> $admin_district
#> [1] "Bristol, City of"
#>
#> $parish
#> [1] "Bristol, City of, unparished area"
#>
#> $admin_county
#> NULL
#>
#> $date_of_introduction
#> [1] "198001"
#>
#> $admin_ward
#> [1] "Hengrove and Whitchurch Park"
#>
#> $ced
#> NULL
#>
#> $ccg
#> [1] "NHS Bristol, North Somerset and South Gloucestershire"
#>
#> $nuts
#> [1] "Bristol, City of"
#>
#> $pfa
#> [1] "Avon and Somerset"
#>
#> $nhs_region
#> [1] "South West"
#>
#> $ttwa
#> [1] "Bristol"
#>
#> $national_park
#> [1] "England (non-National Park)"
#>
#> $bua
#> [1] "Bristol"
#>
#> $icb
#> [1] "NHS Bristol, North Somerset and South Gloucestershire Integrated Care Board"
#>
#> $cancer_alliance
#> [1] "Somerset, Wiltshire, Avon and Gloucestershire"
#>
#> $lsoa11
#> [1] "Bristol 052D"
#>
#> $msoa11
#> [1] "Bristol 052"
#>
#> $lsoa21
#> [1] "Bristol 052D"
#>
#> $msoa21
#> [1] "Bristol 052"
#>
#> $oa21
#> [1] "E00074373"
#>
#> $ruc11
#> [1] "(England/Wales) Urban city and town"
#>
#> $ruc21
#> [1] "Urban: Nearer to a major town or city"
#>
#> $lep1
#> [1] "West of England"
#>
#> $lep2
#> NULL
#>
#> $codes
#> $codes$admin_district
#> [1] "E06000023"
#>
#> $codes$admin_county
#> [1] "E99999999"
#>
#> $codes$admin_ward
#> [1] "E05010902"
#>
#> $codes$parish
#> [1] "E43000019"
#>
#> $codes$parliamentary_constituency
#> [1] "E14001135"
#>
#> $codes$parliamentary_constituency_2024
#> [1] "E14001135"
#>
#> $codes$ccg
#> [1] "E38000222"
#>
#> $codes$ccg_id
#> [1] "15C"
#>
#> $codes$ced
#> [1] "E99999999"
#>
#> $codes$nuts
#> [1] "TLK51"
#>
#> $codes$lsoa
#> [1] "E01014723"
#>
#> $codes$msoa
#> [1] "E02003063"
#>
#> $codes$lau2
#> [1] "E06000023"
#>
#> $codes$pfa
#> [1] "E23000036"
#>
#> $codes$nhs_region
#> [1] "E40000006"
#>
#> $codes$ttwa
#> [1] "E30000180"
#>
#> $codes$national_park
#> [1] "E65000001"
#>
#> $codes$bua
#> [1] "E63012168"
#>
#> $codes$icb
#> [1] "E54000039"
#>
#> $codes$cancer_alliance
#> [1] "E56000033"
#>
#> $codes$lsoa11
#> [1] "E01014723"
#>
#> $codes$msoa11
#> [1] "E02003063"
#>
#> $codes$lsoa21
#> [1] "E01014723"
#>
#> $codes$msoa21
#> [1] "E02003063"
#>
#> $codes$oa21
#> [1] "E00074373"
#>
#> $codes$ruc11
#> [1] "C1"
#>
#> $codes$ruc21
#> [1] "UN1"
#>
#> $codes$lep1
#> [1] "E37000037"
#>
#> $codes$lep2
#> NULL
#>
#>
random_postcode("N1")
#> $postcode
#> [1] "N1 9RD"
#>
#> $quality
#> [1] 1
#>
#> $eastings
#> [1] 530709
#>
#> $northings
#> [1] 183413
#>
#> $country
#> [1] "England"
#>
#> $nhs_ha
#> [1] "London"
#>
#> $longitude
#> [1] -0.116854
#>
#> $latitude
#> [1] 51.5345
#>
#> $european_electoral_region
#> [1] "London"
#>
#> $primary_care_trust
#> [1] "Islington"
#>
#> $region
#> [1] "London"
#>
#> $lsoa
#> [1] "Islington 019B"
#>
#> $msoa
#> [1] "Islington 019"
#>
#> $incode
#> [1] "9RD"
#>
#> $outcode
#> [1] "N1"
#>
#> $parliamentary_constituency
#> [1] "Islington South and Finsbury"
#>
#> $parliamentary_constituency_2024
#> [1] "Islington South and Finsbury"
#>
#> $admin_district
#> [1] "Islington"
#>
#> $parish
#> [1] "Islington, unparished area"
#>
#> $admin_county
#> NULL
#>
#> $date_of_introduction
#> [1] "198001"
#>
#> $admin_ward
#> [1] "Caledonian"
#>
#> $ced
#> NULL
#>
#> $ccg
#> [1] "NHS North Central London"
#>
#> $nuts
#> [1] "Islington"
#>
#> $pfa
#> [1] "Metropolitan Police"
#>
#> $nhs_region
#> [1] "London"
#>
#> $ttwa
#> [1] "London"
#>
#> $national_park
#> [1] "England (non-National Park)"
#>
#> $bua
#> [1] "Islington"
#>
#> $icb
#> [1] "NHS North Central London Integrated Care Board"
#>
#> $cancer_alliance
#> [1] "North Central London"
#>
#> $lsoa11
#> [1] "Islington 019B"
#>
#> $msoa11
#> [1] "Islington 019"
#>
#> $lsoa21
#> [1] "Islington 019B"
#>
#> $msoa21
#> [1] "Islington 019"
#>
#> $oa21
#> [1] "E00013417"
#>
#> $ruc11
#> [1] "(England/Wales) Urban major conurbation"
#>
#> $ruc21
#> [1] "Urban: Nearer to a major town or city"
#>
#> $lep1
#> [1] "London"
#>
#> $lep2
#> NULL
#>
#> $codes
#> $codes$admin_district
#> [1] "E09000019"
#>
#> $codes$admin_county
#> [1] "E99999999"
#>
#> $codes$admin_ward
#> [1] "E05013700"
#>
#> $codes$parish
#> [1] "E43000209"
#>
#> $codes$parliamentary_constituency
#> [1] "E14001306"
#>
#> $codes$parliamentary_constituency_2024
#> [1] "E14001306"
#>
#> $codes$ccg
#> [1] "E38000240"
#>
#> $codes$ccg_id
#> [1] "93C"
#>
#> $codes$ced
#> [1] "E99999999"
#>
#> $codes$nuts
#> [1] "TLI43"
#>
#> $codes$lsoa
#> [1] "E01002697"
#>
#> $codes$msoa
#> [1] "E02000572"
#>
#> $codes$lau2
#> [1] "E09000019"
#>
#> $codes$pfa
#> [1] "E23000001"
#>
#> $codes$nhs_region
#> [1] "E40000003"
#>
#> $codes$ttwa
#> [1] "E30000234"
#>
#> $codes$national_park
#> [1] "E65000001"
#>
#> $codes$bua
#> [1] "E63011980"
#>
#> $codes$icb
#> [1] "E54000028"
#>
#> $codes$cancer_alliance
#> [1] "E56000027"
#>
#> $codes$lsoa11
#> [1] "E01002697"
#>
#> $codes$msoa11
#> [1] "E02000572"
#>
#> $codes$lsoa21
#> [1] "E01002697"
#>
#> $codes$msoa21
#> [1] "E02000572"
#>
#> $codes$oa21
#> [1] "E00013417"
#>
#> $codes$ruc11
#> [1] "A1"
#>
#> $codes$ruc21
#> [1] "UN1"
#>
#> $codes$lep1
#> [1] "E37000051"
#>
#> $codes$lep2
#> NULL
#>
#>
# }